Release History
===============

## 2.0.0 (2019-05-??)
**Improvements**
- Complete rewrite with large improvements
- Reliance on pip is removed and dependencies vendored


## 1.0.12 (2017-12-22)
**Improvements**
- Add version command
- Small check optimization


## 1.0.11 (2017-12-08)
**Improvements**
- Add check for duplicates in requirements and constraints files


## 1.0.10 (2017-11-14)
**Bugfixes**
- Handle possible nonexistent requirement files and missing packages


## 1.0.9 (2017-11-14)
**Improvements**
- Show all constraints that were not set to an exact version


## 1.0.8 (2017-11-08)
**Documentation**
- Fix readme badges


## 1.0.7 (2017-11-08)
**Documentation**
- Rename helper to utility


## 1.0.6 (2017-11-06)
**Documentation**
- Add links to PyPi and license to readme


## 1.0.5 (2017-11-06)
**Documentation**
- Remove changelog link


## 1.0.4 (2017-11-06)
**Documentation**
- Replace history link in readme with file contents


## 1.0.3 (2017-11-06)
**Documentation**
- Update package readme, metadata and changelog


## 1.0.2 (2017-11-06)
**Documentation**
- Update library information.


## 1.0.1 (2017-11-03)
**Bugfixes**
- Fix conflict check function call.


## 1.0.0 (2017-11-03)
- Initial release
